package info.aspirecn.cloud.yysj.controller;

import info.aspirecn.cloud.yysj.model.ResponseInfo;
import info.aspirecn.cloud.yysj.model.response.ExceptionStatistics;
import info.aspirecn.cloud.yysj.model.response.Statistics;
import info.aspirecn.cloud.yysj.service.StatisticsService;
import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestHeader;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import java.util.List;

/**
 * 统计结果信息,用于统计分析页面
 *
 * @author dingliqiang
 */
@Api(tags = "统计结果信息接口（适用于统计分析页面）")
@ApiResponses({
        @ApiResponse(code = 200, message = "成功处理请求"),
        @ApiResponse(code = 400, message = "没有找到该用户信息"),
        @ApiResponse(code = 401, message = "没有权限访问该服务"),
        @ApiResponse(code = 403, message = "权限不足无法访问该服务"),
        @ApiResponse(code = 404, message = "未发现该微服务"),
        @ApiResponse(code = 500, message = "服务器内部错误")
})
@RestController
public class StatisticsController {

    @Autowired
    private StatisticsService statisticsService;

    /**
     * 总订单统计信息接口
     * @param startTime 开始时间
     * @param endTime 结束时间
     * @param userId 用户ID
     * @return 总订单统计信息
     */
    @ApiOperation(value = "总订单统计信息", notes = "获取指定日期内，总订单统计结果信息和一致的结果。")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "endTime", value = "结束时间", dataType = "string", required = true, paramType = "query"),
            @ApiImplicitParam(name = "startTime", value = "开始时间", dataType = "string", required = true, paramType = "query"),
            @ApiImplicitParam(name = "userId", value = "用户ID", dataType = "string", required = true, paramType = "header")
    })
    @GetMapping("/countStatisticsInfo")
    public ResponseInfo getCountStatistics(@RequestParam(required = true) String startTime,
                                            @RequestParam(required = true) String endTime,
                                            @RequestHeader(required = true) String userId) {
        List<Statistics> statisticsList = statisticsService.getCountStatistics(startTime, endTime, userId);
        return new ResponseInfo().setData(statisticsList).setMessage("请求成功");
    }

    /**
     * 异常效验统计信息
     * @param startTime 开始时间
     * @param endTime 结束时间
     * @param userId 用户ID
     * @return
     */
    @ApiOperation(value = "异常效验统计信息", notes = "获取指定日期内，不一致订单统计结果信息。")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "startTime", value = "开始时间", dataType = "string", required = true, paramType = "query"),
            @ApiImplicitParam(name = "endTime", value = "结束时间", dataType = "string", required = true, paramType = "query"),
            @ApiImplicitParam(name = "userId", value = "用户ID", dataType = "string", required = true, paramType = "header")
    })
    @GetMapping("/exceptionStatisticsInfo")
    public ResponseInfo getErrorStatistics(@RequestParam(required = true) String startTime,
                                            @RequestParam(required = true) String endTime,
                                            @RequestHeader(required = true) String userId) {
        List<ExceptionStatistics> exceptionStatisticsList = statisticsService.getErrorStatistics(startTime, endTime, userId);
        return new ResponseInfo().setData(exceptionStatisticsList).setMessage("请求成功");
    }

}
