package info.aspirecn.cloud.yysj.service;

import info.aspirecn.cloud.yysj.model.entity.Produce;
import info.aspirecn.cloud.yysj.model.entity.ProduceRelevance;
import info.aspirecn.cloud.yysj.model.entity.User;
import info.aspirecn.cloud.yysj.model.entity.UserProduce;
import java.util.List;

/**
 * 数据库查询服务接口
 *
 * @author dingliqiang
 */
public interface DbService {


    /**
     * 查询用户信息
     *
     * @param userId 云验平台用户ID
     * @return 云验平台用户信息
     */
    User getUserInfo(String userId);

    /**
     * 查询用户订购产品信息
     * @param userId 云验平台用户ID
     * @return 用户订购产品关联列表
     */
    List<UserProduce> getUserProduceList(String userId);

    /**
     * 查询用户云验平台与数据交互平台关联信息列表
     *
     * @param produceId 云验平台产品ID
     * @return 关联信息列表
     */
    List<ProduceRelevance> getProduceRelevanceList(Integer produceId);

    /**
     * 根据多个产品ID查询对应的产品列表
     *
     * @param produceIdList 产品ID列表
     * @return 云验平台产品列表
     */
    List<Produce> getProduceInfo(List<Integer> produceIdList);

    /**
     * 根据产品ID查询对应的产品信息
     *
     * @param produceId 云验数据平台产品ID
     * @return 云验平台产品信息
     */
    Produce getProduceInfo(Integer produceId);

}
