package info.aspirecn.cloud.yysj.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import info.aspirecn.cloud.yysj.dao.db.ProduceMapper;
import info.aspirecn.cloud.yysj.dao.db.ProduceRelevanceMapper;
import info.aspirecn.cloud.yysj.dao.db.UserMapper;
import info.aspirecn.cloud.yysj.dao.db.UserProduceMapper;
import info.aspirecn.cloud.yysj.exception.UserNotFountException;
import info.aspirecn.cloud.yysj.model.entity.Produce;
import info.aspirecn.cloud.yysj.model.entity.ProduceRelevance;
import info.aspirecn.cloud.yysj.model.entity.User;
import info.aspirecn.cloud.yysj.model.entity.UserProduce;
import info.aspirecn.cloud.yysj.service.DbService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

/**
 * 云验平台数据库查询服务
 *
 * @author dingliqiang
 */
@Service
public class DbServiceImpl implements DbService {

    @Autowired
    private UserProduceMapper userProduceMapper;

    @Autowired
    private ProduceRelevanceMapper produceRelevanceMapper;

    @Autowired
    private ProduceMapper produceMapper;

    @Autowired
    private UserMapper userMapper;

    /**
     * 查询用户信息
     *
     * @param userId 云验平台用户ID
     * @return 云验平台用户信息
     */
    @Override
    public User getUserInfo(String userId) {
        QueryWrapper<User> userQueryWrapper = new QueryWrapper<>();
        userQueryWrapper.eq("userId", userId);
        User user = userMapper.selectOne(userQueryWrapper);
        if (user == null) {
            throw new UserNotFountException("无法查找到该用户");
        }
        return user;
    }

    /**
     * 查询用户订购产品信息
     *
     * @return 用户订购产品关联列表
     */
    @Override
    public List<UserProduce> getUserProduceList(String userId) {
        QueryWrapper<UserProduce> userProduceQueryWrapper = new QueryWrapper<>();
        userProduceQueryWrapper.eq("userId", userId);
        List<UserProduce> yysjProduceList = userProduceMapper.selectList(userProduceQueryWrapper);
        return new ArrayList<>(yysjProduceList);
    }

    /**
     * 查询用户云验平台与数据交互平台关联信息列表
     *
     * @return 关联信息列表
     */
    @Override
    public List<ProduceRelevance> getProduceRelevanceList(Integer produceId) {
        QueryWrapper<ProduceRelevance> produceRelevanceQueryWrapper = new QueryWrapper<>();
        produceRelevanceQueryWrapper.eq("yysjId", produceId);
        List<ProduceRelevance> sjjhProduceIdList = produceRelevanceMapper.selectList(produceRelevanceQueryWrapper);
        return new ArrayList<>(sjjhProduceIdList);
    }

    /**
     * 根据多个产品ID查询对应的产品列表
     *
     * @param produceIdList 产品ID列表
     * @return 云验平台产品列表
     */
    @Override
    public List<Produce> getProduceInfo(List<Integer> produceIdList) {
        QueryWrapper<Produce> produceQueryWrapper = new QueryWrapper<>();
        produceQueryWrapper.in("id", produceIdList);
        List<Produce> produceList = produceMapper.selectList(produceQueryWrapper);
        return new ArrayList<>(produceList);
    }

    /**
     * 根据产品ID查询对应的产品信息
     *
     * @param produceId 云验数据平台产品ID
     * @return 云验平台产品信息
     */
    @Override
    public Produce getProduceInfo(Integer produceId) {
        QueryWrapper<Produce> produceQueryWrapper = new QueryWrapper<>();
        produceQueryWrapper.eq("id", produceId);
        return produceMapper.selectOne(produceQueryWrapper);
    }

}
